@@ -1,3 +1,13 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
+# This file is part of convertdate.
+# http://github.com/fitnr/convertdate
+
+# Licensed under the MIT license:
+# http://opensource.org/licenses/MIT
+# Copyright (c) 2016, fitnr <fitnr@fakeisthenewreal>
+
 # Most of this code is ported from Fourmilab's javascript calendar converter
 # http://www.fourmilab.ch/documents/calendar/
 # which was developed by John Walker
@@ -6,29 +16,32 @@
 # Meeus, Jean. Astronomical Algorithms . Richmond: Willmann-Bell, 1991. ISBN 0-943396-35-2.
 #    The essential reference for computational positional astronomy.
 #
-
-__version__ = "2.0.3.1"
-
-__all__ = [
-    'holidays', 'astro', 'utils', 'bahai',
-    'french_republican', 'gregorian', 'hebrew',
-    'indian_civil', 'islamic', 'iso',
-    'julian', 'mayan', 'persian', 'mayan',
-    'ordinal',
-]
-
 from . import bahai
+from . import coptic
+from . import daycount
 from . import dublin
 from . import french_republican
 from . import gregorian
 from . import hebrew
 from . import holidays
 from . import indian_civil
+from . import iso
 from . import islamic
 from . import julian
 from . import julianday
 from . import mayan
 from . import persian
-from . import mayan
+from . import positivist
 from . import ordinal
 
+__version__ = '2.1.3'
+
+__all__ = [
+    'holidays', 'bahai', 'coptic', 'dublin',
+    'daycount',
+    'french_republican', 'gregorian', 'hebrew',
+    'indian_civil', 'islamic', 'iso',
+    'julian', 'julianday',
+    'mayan', 'persian', 'positivist', 'mayan',
+    'ordinal',
+]
