@@ -1,8 +1,16 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
+
+# This file is part of convertdate.
+# http://github.com/fitnr/convertdate
+
+# Licensed under the MIT license:
+# http://opensource.org/licenses/MIT
+# Copyright (c) 2016, fitnr <fitnr@fakeisthenewreal>
 import time
+import calendar
 from math import trunc
 from .utils import nth_day_of_month
-import calendar
 from . import hebrew
 
 # weekdays
@@ -111,7 +119,7 @@ def flag_day(year):
     return (year, JUN, 14)
 
 
-def indepedence_day(year, observed=None):
+def independence_day(year, observed=None):
     '''July 4th'''
     day = 4
 
@@ -202,6 +210,16 @@ def hanukkah(year, eve=None):
     return year, month, day
 
 
+def purim(year, eve=None):
+    if not hebrew.leap(year + hebrew.HEBREW_YEAR_OFFSET):
+        year, month, day = hebrew.to_jd_gregorianyear(year, hebrew.ADAR, 14)
+    else:
+        year, month, day = hebrew.to_jd_gregorianyear(year, hebrew.VEADAR, 14)
+    if eve:
+        day = day - 1
+    return year, month, day
+
+
 def rosh_hashanah(year, eve=None):
     year, month, day = hebrew.to_jd_gregorianyear(year, hebrew.TISHRI, 1)
     if eve:
@@ -210,10 +228,9 @@ def rosh_hashanah(year, eve=None):
 
 
 def yom_kippur(year, eve=None):
-    year, month, day = hebrew.to_jd_gregorianyear(year, TISHRI, 10)
+    year, month, day = hebrew.to_jd_gregorianyear(year, hebrew.TISHRI, 10)
     if eve:
         day = day - 1
-
     return year, month, day
 
 
@@ -221,9 +238,23 @@ def passover(year, eve=None):
     year, month, day = hebrew.to_jd_gregorianyear(year, hebrew.NISAN, 15)
     if eve:
         day = day - 1
-
     return year, month, day
 
+
+def shavuot(year, eve=None):
+    year, month, day = hebrew.to_jd_gregorianyear(year, hebrew.SIVAN, 6)
+    if eve:
+        day = day - 1
+    return year, month, day
+
+
+def sukkot(year, eve=None):
+    year, month, day = hebrew.to_jd_gregorianyear(year, hebrew.TISHRI, 15)
+    if eve:
+        day = day - 1
+    return year, month, day
+
+
 # Mexican holidays
 
 
@@ -257,6 +288,9 @@ class Holidays(object):
     def set_year(self, year):
         self.year = year
 
+    def __repr__(self):
+        return 'Holidays({})'.format(self.year)
+
     # the holidays...
     @property
     def christmas(self):
@@ -279,8 +313,8 @@ class Holidays(object):
         return new_years_eve(self.year)
 
     @property
-    def indepedence_day(self, observed=None):
-        return indepedence_day(self.year, observed)
+    def independence_day(self):
+        return independence_day(self.year, observed=True)
 
     @property
     def flag_day(self):
@@ -330,9 +364,14 @@ class Holidays(object):
     def mothers_day(self):
         return mothers_day(self.year)
 
+    @property
     def fathers_day(self):
         return fathers_day(self.year)
 
+    @property
+    def pulaski_day(self):
+        return pulaski_day(self.year)
+
     @property
     def easter(self):
         return easter(self.year)
@@ -342,21 +381,49 @@ class Holidays(object):
         return martin_luther_king_day(self.year)
 
     @property
-    def hanukkah(self, eve=None):
-        return hanukkah(self.year, eve)
+    def hanukkah(self):
+        return hanukkah(self.year, eve=False)
 
     @property
-    def rosh_hashanah(self, eve=None):
-        return rosh_hashanah(self.year, eve)
+    def purim(self):
+        return purim(self.year, eve=False)
 
     @property
-    def yom_kippur(self, eve=None):
-        return yom_kippur(self.year, eve)
+    def rosh_hashanah(self):
+        return rosh_hashanah(self.year, eve=False)
 
     @property
-    def passover(self, eve=None):
-        return passover(self.year, eve)
+    def yom_kippur(self):
+        return yom_kippur(self.year, eve=False)
+
+    @property
+    def passover(self):
+        return passover(self.year, eve=False)
+
+    @property
+    def shavuot(self):
+        return shavuot(self.year, eve=False)
+
+    @property
+    def sukkot(self):
+        return sukkot(self.year, eve=False)
+
+    @property
+    def dia_constitucion(self):
+        return dia_constitucion(self.year, observed=True)
+
+    @property
+    def natalicio_benito_juarez(self):
+        return natalicio_benito_juarez(self.year, observed=True)
+
+    @property
+    def dia_independencia(self):
+        return dia_independencia(self.year)
+
+    @property
+    def dia_revolucion(self):
+        return dia_revolucion(self.year)
 
 
 if __name__ == '__main__':
-    holiday = Holidays(2014)
+    holiday = Holidays(time.localtime().tm_year)
