@@ -1,4 +1,12 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
+
+# This file is part of convertdate.
+# http://github.com/fitnr/convertdate
+
+# Licensed under the MIT license:
+# http://opensource.org/licenses/MIT
+# Copyright (c) 2016, fitnr <fitnr@fakeisthenewreal>
 from math import trunc
 from .utils import jwday, monthcalendarhelper
 from .gregorian import to_jd as gregorian_to_jd, from_jd as gregorian_from_jd
@@ -36,7 +44,7 @@ def legal_date(year, month, day):
     daysinmonth = month_length(year, month)
 
     if not (0 < day <= daysinmonth):
-        raise IndexError("Month {} doesn't have a day {}".format(month, day))
+        raise ValueError("Month {} doesn't have a day {}".format(month, day))
 
     return True
 
