@@ -1,3 +1,12 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
+# This file is part of convertdate.
+# http://github.com/fitnr/convertdate
+
+# Licensed under the MIT license:
+# http://opensource.org/licenses/MIT
+# Copyright (c) 2016, fitnr <fitnr@fakeisthenewreal>
 from math import trunc
 from calendar import isleap
 from . import gregorian
@@ -28,7 +37,7 @@ def from_gregorian(year, month, day):
 def to_gregorian(year, dayofyear):
     leap = isleap(year)
 
-    if dayofyear > 59 + leap:
+    if dayofyear < 59 + leap:
         leap_adj = 0
     elif leap:
         leap_adj = 1
